/////////////////////////////////////////////////
// Implementacija klase CCaptureWnd
// 
// Copyright (c) Predrag Drljaca
//
//
#include "StdAfx.h"
#include "CaptureWnd.h"

#define KEYNAME     "Software\\Microsoft\\Multimedia Tools\\"
#define ROOTKEY     HKEY_CURRENT_USER

IMPLEMENT_DYNCREATE(CCaptureWnd, CVideoWnd)

BEGIN_MESSAGE_MAP(CCaptureWnd, CVideoWnd)
	//{{AFX_MSG_MAP(CCaptureWnd)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()


CCaptureWnd::CCaptureWnd()
{
	bConnected=FALSE;
	CapDriverCaps.fHasDlgVideoFormat=FALSE;
	CapDriverCaps.fHasDlgVideoSource=FALSE;
	CapDriverCaps.fHasDlgVideoDisplay=FALSE;
	CapDriverCaps.fHasOverlay=FALSE; 
}

CCaptureWnd::~CCaptureWnd()
{
	if (bConnected) DriverDisconnect();
	WriteSettings();
}

BOOL CCaptureWnd::InitHardware()
{
	BOOL bOK;
	bConnected=bOK=DriverConnect(0);
	DriverGetCaps(CapDriverCaps);
	GetStatus(CapStatus);

	ReadSettings();
	PreviewRate(bOK? 33:0);
	
	if (bOverlay)
	{
		Overlay(TRUE);
		Preview(FALSE);
	}
	else
	{
		Preview(TRUE);
	}

	if (bOK) 
	{
		ResizeWnd();
		PreviewScale(TRUE);
	}

	FileSetCaptureFile(CaptureFile);
	return bOK;
}

void CCaptureWnd::ResizeWnd()
{
	GetStatus(CapStatus);
	SetWindowPos(&wndTop,0,0,
			   CapStatus.uiImageWidth,
			   CapStatus.uiImageHeight,
			   NULL);
}



void CCaptureWnd::ReadSettings()
{
	bOverlay = regGetProfileInt("VidCap", "OverlayWindow", FALSE);
	bLive = regGetProfileInt("VidCap", "LiveWindow", TRUE);
	regGetProfileString("VidCap", "CaptureFile", "",CaptureFile, sizeof(CaptureFile));
}

void CCaptureWnd::WriteSettings()
{
	regWriteProfileInt("VidCap", "OverlayWindow", bOverlay, TRUE);
	regWriteProfileInt("VidCap", "LiveWindow", bLive, TRUE);
	regWriteProfileString("VidCap", "CaptureFile", CaptureFile);
}


UINT CCaptureWnd::regGetProfileInt(LPSTR appname, LPSTR valuename, UINT uDefault)
{
    char achName[MAX_PATH];
    HKEY hkey;
    DWORD dwType;
    UINT value = uDefault;
    DWORD dwData;
    unsigned long cbData;


    lstrcpy(achName, KEYNAME);
    lstrcat(achName, appname);
    if (RegOpenKey(ROOTKEY, achName, &hkey) != ERROR_SUCCESS) {
        return(uDefault);
    }

    cbData = sizeof(dwData);
    if (RegQueryValueEx(
        hkey,
        valuename,
        NULL,
        &dwType,
        (PBYTE) &dwData,
        &cbData) == ERROR_SUCCESS) {
            if (dwType == REG_DWORD) {
                value = (UINT)dwData;
            }
    }

    RegCloseKey(hkey);

    return(value);
}

void CCaptureWnd::regWriteProfileInt(LPSTR appname, LPSTR valuename, UINT uValue, UINT uDefault)
{
    if (regGetProfileInt(appname, valuename, uDefault) == uValue) 
	{
        return;
    }

    char achName[MAX_PATH];
    HKEY hkey;
    DWORD dwData = uValue;
    lstrcpy(achName, KEYNAME);
    lstrcat(achName, appname);
    if (RegCreateKey(ROOTKEY, achName, &hkey) == ERROR_SUCCESS) 
	{
		RegSetValueEx(
                      hkey,
					  valuename,
					  0,
					  REG_DWORD,
					  (PBYTE) &dwData,
					  sizeof(dwData)
					);

        RegCloseKey(hkey);
    }

}

DWORD CCaptureWnd::regGetProfileString(LPSTR appname,
									  LPSTR valuename,
									  LPSTR pDefault,
									  LPSTR pResult,
									  unsigned long cbResult)
{
    char achName[MAX_PATH];
    HKEY hkey;
    DWORD dwType;

    lstrcpy(achName, KEYNAME);
    lstrcat(achName, appname);
    if (RegOpenKey(ROOTKEY, achName, &hkey) == ERROR_SUCCESS) {

        if (RegQueryValueEx(
            hkey,
            valuename,
            NULL,
            &dwType,
            (PBYTE)pResult,
            &cbResult) == ERROR_SUCCESS) {

                if (dwType == REG_SZ) {
                    RegCloseKey(hkey);
                    return(cbResult - 1);
                }
        }


        RegCloseKey(hkey);
    }

    lstrcpy(pResult, pDefault);
    return(lstrlen(pDefault));
}

void CCaptureWnd::regWriteProfileString(LPSTR appname, LPSTR valuename, LPSTR pData)
{
   char Name[MAX_PATH];
   HKEY hkey;
   lstrcpy(Name, KEYNAME);
   lstrcat(Name, appname);
   if (RegCreateKey(ROOTKEY, Name, &hkey) == ERROR_SUCCESS) 
   {
        RegSetValueEx(
            hkey,
            valuename,
            0,
            REG_SZ,
            (PBYTE)pData,
            lstrlen(pData) + 1);
        RegCloseKey(hkey);
    }

}


LRESULT CCaptureWnd::OnFrame(LPVIDEOHDR lpVH)
{
	//Posle hvatanja framea mzemo doci da pokupimo slikicu
	return TRUE;
}

