//////////////////////////////////////////////////////////////
// CVideoWnd : MFC Video klasa
// Copyright (c) Drljaca Predrag 1997-98
//
// Implementacija klase CVideoWnd
//////////////////////////////////////////////////////////////

#include "StdAfx.h"
#include "VideoWnd.h"

///////
// Deklaracija privatnih funkija preuzetih iz afxpriv.h
// zelim da trepujem WM_CREATE da bih konektovao moje CALLBACK
// funkcije

void AFXAPI AfxHookWindowCreate(CWnd* pWnd);
BOOL AFXAPI AfxUnhookWindowCreate();


IMPLEMENT_DYNCREATE(CVideoWnd, CWnd)


BEGIN_MESSAGE_MAP(CVideoWnd, CWnd)
	//{{AFX_MSG_MAP(CVideoWnd)
	ON_WM_CREATE()
	ON_WM_DESTROY()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

//////////////////////////////////////////////////////////////
// Standardni konstruktor i destruktor za klasu

CVideoWnd::CVideoWnd()
{

}

CVideoWnd::~CVideoWnd()
{
	if (m_hWnd != NULL)
		DestroyWindow();
}

//////////////////
// Kreiramo Capture prozor. 
// Zovemo VFW funkciju za kreiranje.
// kreiranje preuzeto iz wincore.cpp, Microsoft  delo
//
BOOL CVideoWnd::Create(LPCSTR lpszTitle, DWORD dwStyle,
	int nID, CRect& rc, CWnd* pWndParent)
{
	AfxHookWindowCreate(this);
	HWND hWnd = capCreateCaptureWindow(lpszTitle,
		dwStyle,
		rc.left, 
		rc.top, 
		rc.Width(), 
		rc.Height(),
		pWndParent->GetSafeHwnd(),
		nID);
	if (!AfxUnhookWindowCreate())
			PostNcDestroy();
	if (hWnd == NULL)
			return FALSE;
	ASSERT(hWnd == m_hWnd);
	return TRUE;
}

//////////////////
// Inicijalizujemo prozor a zatim instaliramo callback funkcije
// Install callbacks.
//
int CVideoWnd::OnCreate(LPCREATESTRUCT lpcs)
{
	if (CWnd::OnCreate(lpcs) == -1)
		return -1;

	// Postavljamo Callback funkcije
	capSetCallbackOnCapControl (m_hWnd, CBCapControl);
	capSetCallbackOnError      (m_hWnd, CBError);
	capSetCallbackOnFrame      (m_hWnd, CBFrame);
	capSetCallbackOnStatus     (m_hWnd, CBStatus);
	capSetCallbackOnVideoStream(m_hWnd, CBVideoStream);
	capSetCallbackOnWaveStream (m_hWnd, CBWaveStream);
	capSetCallbackOnYield      (m_hWnd, CBYield);

	return 0;
}

//////////////////
// Prozor se unistava znaci deinstaliramo callback funkcije
//
void CVideoWnd::OnDestroy()
{
	capSetCallbackOnCapControl (m_hWnd, NULL);
	capSetCallbackOnError      (m_hWnd, NULL);
	capSetCallbackOnFrame      (m_hWnd, NULL);
	capSetCallbackOnStatus     (m_hWnd, NULL);
	capSetCallbackOnVideoStream(m_hWnd, NULL);
	capSetCallbackOnWaveStream (m_hWnd, NULL);
	capSetCallbackOnYield      (m_hWnd, NULL);

	CWnd::OnDestroy();
}

////////////////////////////////////////////////////////////////
// Konvertujemo callback funkcije u virtualne funkcije 
// CVideoWnd-a
//

LRESULT PASCAL CVideoWnd::CBCapControl(HWND hwnd)
{
        CVideoWnd* pVideoWin = (CVideoWnd*)FromHandlePermanent(hwnd);
	return pVideoWin->OnCapControl();
}

LRESULT CVideoWnd::OnCapControl()
{
	return TRUE;					
}

LRESULT PASCAL CVideoWnd::CBError(HWND hwnd, int id, LPSTR msg)
{
        CVideoWnd* pVideoWin = (CVideoWnd*)FromHandlePermanent(hwnd);
	return pVideoWin->OnError(id, msg);
}

LRESULT CVideoWnd::OnError(int /*id*/, LPSTR /*msg*/)
{
	return TRUE;
}

LRESULT PASCAL CVideoWnd::CBFrame(HWND hwnd, LPVIDEOHDR lpVH)
{
        CVideoWnd* pVideoWin = (CVideoWnd*)FromHandlePermanent(hwnd);
	return pVideoWin->OnFrame(lpVH);
}

LRESULT CVideoWnd::OnFrame(LPVIDEOHDR /* lpVH */)
{
	return TRUE;
}


LRESULT PASCAL CVideoWnd::CBStatus(HWND hwnd, int id, LPSTR msg)
{
        CVideoWnd* pVideoWin = (CVideoWnd*)FromHandlePermanent(hwnd);
	return pVideoWin->OnStatus(id, msg);
}

LRESULT CVideoWnd::OnStatus(int /*id*/, LPSTR /* msg*/)
{
	return TRUE;
}

LRESULT PASCAL CVideoWnd::CBVideoStream(HWND hwnd, LPVIDEOHDR lpVH)
{
        CVideoWnd* pVideoWin = (CVideoWnd*)FromHandlePermanent(hwnd);
	return pVideoWin->OnVideoStream(lpVH);
}

LRESULT CVideoWnd::OnVideoStream(LPVIDEOHDR /* lpVH */)
{
	return TRUE;
}

LRESULT PASCAL CVideoWnd::CBWaveStream(HWND hwnd, LPWAVEHDR lpWH)
{
        CVideoWnd* pVideoWin = (CVideoWnd*)FromHandlePermanent(hwnd);
	return pVideoWin->OnWaveStream(lpWH);
}

LRESULT CVideoWnd::OnWaveStream(LPWAVEHDR /* lpWH */)
{
	return TRUE;
}

LRESULT PASCAL CVideoWnd::CBYield(HWND hwnd)
{
        CVideoWnd* pVideoWin = (CVideoWnd*)FromHandlePermanent(hwnd);
	return pVideoWin->OnYield();
}

LRESULT CVideoWnd::OnYield()
{
	return TRUE;					
}

////////////////////////////////////////////////////////////////
// Mala pomoc za dobijanje opisa drajvera kao CString a ne kao
//*char

CString CVideoWnd::GetDriverDescription(WORD iDriver)
{
	char DeviceNameAndVersion[160];
	char DeviceVersion[80];
	if(capGetDriverDescription(iDriver, (LPSTR)DeviceNameAndVersion, 
									 sizeof(DeviceNameAndVersion), 
									 (LPSTR)DeviceVersion, 
									 sizeof(DeviceVersion)))
	{
		lstrcat (DeviceNameAndVersion, ",   ");
		lstrcat (DeviceNameAndVersion, DeviceVersion);
		return CString(DeviceNameAndVersion);	
	}
	else
		return CString("NULL");
}

